@@ -516,6 +516,7 @@ public:
     else if (model==generateAction &&
              generateAction->IsFinished()) {
       if (ShowGenerateDialog(this,generateTask.minimumPoints)) {
+        targetLevelPoints=generateTask.minimumPoints;
         GenerateRiddle();
       }
     }
@@ -555,6 +556,15 @@ public:
     }
     else if (model==statAction &&
              statAction->IsFinished()) {
+      /*
+      if (GetWindow()->IsFullScreen()) {
+        GetWindow()->LeaveFullScreen();
+      }
+      else {
+        GetWindow()->SetFullScreen();
+      }
+      return;*/
+
       Sudoku game;
       Sudoku riddle;
       Sudoku solution;
